@@ -4,10 +4,12 @@
   # Check Java version. 
   # See https://cran.r-project.org/doc/manuals/r-release/R-exts.html#Writing-portable-packages
   v <- rJava::.jcall("java/lang/System", "S", "getProperty", "java.runtime.version")
-  v <- as.numeric(paste0(strsplit(v, "[.]")[[1L]][1:2], collapse = "."))
-  if(v < 1.8) stop("Java 8 is required for this package.")
+  if(substr(v, 1L, 2L) == "1.") {
+    v <- as.numeric(paste0(strsplit(v, "[.]")[[1L]][1:2], collapse = "."))
+    if(v < 1.8) stop("Java 8 or above is required for this package.")
+  }
   
-  # Creating these objects via rJava is slow, so instantiate them only once and
+  # Creating these objects via rJava is slow, so instantiate them once and
   # re-use them to improve performance.
   assign("jdx.utility", rJava::.jnew("org/fgilbert/jdx/Utility"), inherits = TRUE)
   assign("jdx.j2r", createJavaToRobject(), inherits = TRUE)
